pub struct ForeignElement<F: Field, const B: usize, const N: usize> {
pub limbs: [F; N],
len: usize,
}Expand description
Represents a foreign field element Represents a foreign field element
Fields
limbs: [F; N]limbs in little endian order
len: usizenumber of limbs used for the foreign field element
Implementations
Sourceimpl<F: Field, const B: usize, const N: usize> ForeignElement<F, B, N>
impl<F: Field, const B: usize, const N: usize> ForeignElement<F, B, N>
Sourcepub const fn new(limbs: [F; N]) -> Self
pub const fn new(limbs: [F; N]) -> Self
Creates a new foreign element from an array containing N limbs
Sourcepub fn from_biguint(big: &BigUint) -> Self
pub fn from_biguint(big: &BigUint) -> Self
Sourcepub fn neg(&self, modulus: &BigUint) -> Self
pub fn neg(&self, modulus: &BigUint) -> Self
Initializes a new foreign element from an absolute BigUint but the equivalent
foreign element obtained corresponds to the negated input. It first converts the
input big element to a big integer modulo the foreign field modulus, and then
computes the negation of the result.
Sourcepub fn from_be(bytes: &[u8]) -> Self
pub fn from_be(bytes: &[u8]) -> Self
Initializes a new foreign element from a set of bytes in big endian
Sourcepub fn to_biguint(&self) -> BigUint
pub fn to_biguint(&self) -> BigUint
Obtains the big integer representation of the foreign field element
Sourcefn big_to_vec(fe: &BigUint) -> Vec<F>
fn big_to_vec(fe: &BigUint) -> Vec<F>
Split a foreign field element into a vector of B (limb bitsize) bits field
elements of type F in little-endian. Right now it is written
so that it gives N (limb count) limbs, even if it fits in less bits.
Sourceimpl<F: PrimeField, const B: usize, const N: usize> ForeignElement<F, B, N>
impl<F: PrimeField, const B: usize, const N: usize> ForeignElement<F, B, N>
Sourcepub fn from_field(field: F) -> Self
pub fn from_field(field: F) -> Self
Initializes a new foreign element from an element in the native field