cfg_chunks_mut

Macro cfg_chunks_mut 

macro_rules! cfg_chunks_mut {
    ($e:expr, $size:expr) => { ... };
}
Returns a parallel iterator over mutable chunks when the parallel feature is enabled, otherwise returns a sequential one.