cfg_into_iter

Macro cfg_into_iter 

macro_rules! cfg_into_iter {
    ($e:expr) => { ... };
}
Returns a parallel consuming iterator when the parallel feature is enabled, otherwise returns a sequential consuming iterator.